upper_bound_always

Function upper_bound_always 

pub fn upper_bound_always(search: Result<usize, usize>, cap: usize) -> usize
Returns the index of the smallest element greater than or equal to the search key, or the last index.